# this script generates data needed to verify all claims about
# Erdos' function f(n,7,3) as stated in arxiv:1203.4393v4
# NB: we take complements (forbid triangle and minimise number of indep 7-sets)
from flagmatic.all import *

problem = GraphProblem(8, forbid_induced=(3,3), density=(7,0), minimize=True)
problem.set_inactive_types(1, 3, 4, 5, 6, 7, 8, 10)
construction = GraphBlowupConstruction("g:12131415162728292a373b3c3d484b4e4f595c5e5g6a6d6f6g7e7f7g8c8d8g9b9d9fabacaebgcfde")
problem.set_extremal_construction(construction)
problem.solve_sdp(show_output=True, solver="sdpa_dd")
problem.make_exact(2^40)
# Number of 8-vertex graphs that appear in the construction
# Number of sharp graphs 
# if equal, then these lists coincide by Lemma 5 in arxiv:1203.4393v4
print len(construction.subgraphs(8)),len(problem._sharp_graphs)
# rank condition of Section 4.3 in arxiv:1203.4393v4 for type tau_{37}
print problem.types[36]
print problem._exact_Q_matrices[36].nrows()
print problem._exact_Q_matrices[36].rank()
problem.write_certificate("73.js")

# we verify Claim 16 in arxiv:1203.4393v4
subproblem = GraphProblem(7, forbid_induced=[(3, 3), "6:1223344551"], density=(7, 0), minimize=True)
subproblem.solve_sdp(show_output=True)
subproblem.make_exact()
# we check if the obtained bound is larger than c_{7,3}
print subproblem._bound - 98491/16777216
subproblem.write_certificate("73a.js")
